@@ -50,6 +50,7 @@
 #include "segatex_setenforce.h"
 #include "segatex_yum.h"
 #include "segatex_yum_process.h"
+#include "segatex_audit2allow.h"
 #include "mainwindow.h"
 
 MainWindow::MainWindow(QWidget *parent, const char *name)
@@ -76,9 +77,10 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	selpaw1 = new Selpaw();
 	selpawadjust1 = new SelpawAdjust();
 	segatex_state = new SegatexState();
-	//needs here to be declared
+	//needs here to be declared when opening a new window unless segmentation fualt happens...
 	segatex_apply = 0;
 	selinux_yum = 0;
+	selinux_audit2allow = 0;
 
 	//connect SIGNAL to objects    
 
@@ -94,7 +96,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	createToolBars();
 	createStatusBar();
 
-	setCaption(tr("segatex_suite-1.3"));
+	setCaption(tr("segatex_suite-1.4"));
 	setIcon(QPixmap::fromMimeSource("icon.png"));
 }
 
@@ -373,6 +375,11 @@ void MainWindow::createActions()
 	selinuxYumAct->setStatusTip(tr("Yum install/update SELinux related RPMs."));
 	connect(selinuxYumAct, SIGNAL(activated()), this, SLOT(yum_selinux()));
 	connect(selinuxYumAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	audit2allowAct = new QAction(tr("&Audit2allow"), 0, this);
+	audit2allowAct->setStatusTip(tr("audit2allow"));
+	connect(audit2allowAct, SIGNAL(activated()), this, SLOT(audit2allow()));
+	connect(audit2allowAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 }
 
 void MainWindow::createMenus()
@@ -434,6 +441,8 @@ void MainWindow::createMenus()
 
 	//newly added
 	policyMenu = new QPopupMenu(this);
+
+	audit2allowAct->addTo(policyMenu);
 	selinuxYumAct->addTo(policyMenu);
 	enforcingAct->addTo(policyMenu);
 	check_selinuxAct->addTo(policyMenu);
@@ -787,7 +796,7 @@ void MainWindow::notice()
 void MainWindow::about()
 {
     QMessageBox::about(this, tr("About segatex_suite"),
-            tr("<h2>segatex_suite-1.3</h2>"
+            tr("<h2>segatex_suite-1.4</h2>"
                "<p>Copyright &copy; 2007 Shintaro Fujiwara."
                "<p>segatex_suite is a SELinux tool"
                "<b>written with Qt</b>."));
@@ -924,3 +933,12 @@ void MainWindow::yum_selinux()
 	selinux_yum->raise();
 	selinux_yum->setActiveWindow();
 }
+void MainWindow::audit2allow()
+{
+	if(!selinux_audit2allow) {
+		selinux_audit2allow = new SegatexAudit2allow(this);
+	}
+	selinux_audit2allow->show();
+	selinux_audit2allow->raise();
+	selinux_audit2allow->setActiveWindow();
+}
