@@ -47,6 +47,7 @@ class SegatexApply;
 class SegatexSetenforce;
 class SegatexYum;
 class SegatexYumProcess;
+class SegatexAudit2allow;
 
 class MainWindow : public QMainWindow
 {
@@ -91,6 +92,7 @@ private slots:
     void howtouse();
     void enforcing();
     void yum_selinux();
+    void audit2allow();
 
     void save();
     void saveAs();
@@ -151,6 +153,7 @@ private:
     SegatexApply *segatex_apply;
     SegatexSetenforce *segatex_apply_for_state;
     SegatexYum *selinux_yum;
+    SegatexAudit2allow *selinux_audit2allow;
     
     QPopupMenu *fileMenu;
     QPopupMenu *editMenu;
@@ -209,6 +212,7 @@ private:
     QAction *check_selinuxAct;
     QAction *default_policyAct;
     QAction *selinuxYumAct;
+    QAction *audit2allowAct;
 };
 
 #endif
