@@ -1,8 +1,7 @@
 /*
- * segatex_editor SELinux tool.
+ * segatex SELinux tool.
  *
  * Copyright (C) 2007 Shintaro Fujiwara 
- * shintaro.fujiwara@gmai.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,14 +24,13 @@
 
 class ParseLinesAdmin: public ParseLines
 {
-    Q_OBJECT
+	Q_OBJECT
 public:
-    ParseLinesAdmin();
-    ParseLinesAdmin(QSplitter*&);
-    ~ParseLinesAdmin();
+	ParseLinesAdmin();
+	ParseLinesAdmin(QSplitter*&);
 public slots:
-    void parse_admin();
-    void break_admin();
+	void parse_admin();
+	void break_admin();
 };
 
 #endif
