@@ -1,8 +1,7 @@
 /*
- * segatex_editor SELinux tool.
+ * segatex SELinux tool.
  *
  * Copyright (C) 2007 Shintaro Fujiwara 
- * shintaro.fujiwara@gmai.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,14 +25,13 @@
 
 class ParseLinesApps: public ParseLines
 {
-    Q_OBJECT
+	Q_OBJECT
 public:
-    ParseLinesApps();
-    ParseLinesApps(QSplitter*&);
-    ~ParseLinesApps();
+	ParseLinesApps();
+	ParseLinesApps(QSplitter*&);
 public slots:
-    void parse_apps();
-    void break_apps();
+	void parse_apps();
+	void break_apps();
 };
 
 #endif
