@@ -1,8 +1,7 @@
 /*
- * segatex_editor SELinux tool.
+ * segatex SELinux tool.
  *
  * Copyright (C) 2007 Shintaro Fujiwara 
- * shintaro.fujiwara@gmai.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,15 +25,14 @@
 
 class ParseLinesKernel: public ParseLines
 {
-    Q_OBJECT
+	Q_OBJECT
 public:
-    ParseLinesKernel();
-    ParseLinesKernel(QSplitter*&);
-    ~ParseLinesKernel();
+	ParseLinesKernel();
+	ParseLinesKernel(QSplitter*&);
 public slots:
-    void parse_kernel();
-    void parse_kernel_prepare();
-    void break_kernel();
+	void parse_kernel();
+	void parse_kernel_prepare();
+	void break_kernel();
 };
 
 #endif
