@@ -1,6 +1,6 @@
 /*
- * segatex_editor SELinux tool.
- *
+ * segatex SELinux tool.
+ * 
  * Copyright (C) 2007 Shintaro Fujiwara 
  * shintaro.fujiwara@gmai.com
  *
@@ -22,8 +22,8 @@
 #include "parselines_selpaw.h"
 
 //for debug
-#include <iostream>
-using namespace std;
+//#include <iostream>
+//using namespace std;
 
 //default constructor
 ParseLinesSelpaw::ParseLinesSelpaw(){}
