@@ -1,8 +1,7 @@
 /*
- * segatex_editor SELinux tool.
+ * segatex SELinux tool.
  *
  * Copyright (C) 2007 Shintaro Fujiwara 
- * shintaro.fujiwara@gmai.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,14 +25,13 @@
 
 class ParseLinesSystem: public ParseLines
 {
-    Q_OBJECT
+	Q_OBJECT
 public:
-    ParseLinesSystem();
-    ParseLinesSystem(QSplitter*&);
-    ~ParseLinesSystem();
+	ParseLinesSystem();
+	ParseLinesSystem(QSplitter*&);
 public slots:
-    void parse_system();
-    void break_system();
+	void parse_system();
+	void break_system();
 };
 
 #endif
