@@ -1,8 +1,7 @@
 /*
- * segatex_editor SELinux tool.
+ * segatex SELinux tool.
  *
  * Copyright (C) 2007 Shintaro Fujiwara 
- * shintaro.fujiwara@gmai.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -774,5 +773,3 @@ void SelpawAdjust::sort_selpaw_summary()
 	}
 	file_w.close();
 }//end-sort_selpaw_summary
-
-SelpawAdjust::~SelpawAdjust(){}
